from web3 import Web3

class CV:
    #dex
    cv_route=Web3.to_checksum_address('0x3C351E1afdd1b1BC44e931E12D4E05D6125eaeCa')
    cv_factory=Web3.to_checksum_address('0x794C07912474351b3134E6D6B3B7b3b4A07cbAAa')

class AddressCV:
    #dex
    cv_route=Web3.to_checksum_address('0x3C351E1afdd1b1BC44e931E12D4E05D6125eaeCa')
    cv_factory=Web3.to_checksum_address('0x794C07912474351b3134E6D6B3B7b3b4A07cbAAa')

class AddressSynapseCV:
    cv_l1_bridge_zap=Web3.to_checksum_address('0x75224b0f245Fe51d5bf47A898DbB6720D4150BA7')

class DfkTokens:
    #erc20
    crystal=Web3.to_checksum_address("0x04b9dA42306B023f3572e106B11D82aAd9D32EBb")
    xjewel=Web3.to_checksum_address("0x77f2656d04E158f915bC22f07B779D94c1DC47Ff")
    wjewel=Web3.to_checksum_address("0xCCb93dABD71c8Dad03Fc4CE5559dC3D89F67a260")
    avax=Web3.to_checksum_address("0xB57B60DeBDB0b8172bb6316a9164bd3C695F133a")
    usdc=Web3.to_checksum_address("0x3AD9DFE640E1A9Cc1D9B0948620820D975c3803a")
    eth=Web3.to_checksum_address("0xfBDF0E31808d0aa7b9509AA6aBC9754E48C58852")
    btc=Web3.to_checksum_address("0x7516EB8B8Edfa420f540a162335eACF3ea05a247")
    klay=Web3.to_checksum_address("0x97855Ba65aa7ed2F65Ed832a776537268158B78a")
    matic=Web3.to_checksum_address("0xD17a41Cd199edF1093A9Be4404EaDe52Ec19698e")
    ftm=Web3.to_checksum_address("0x2Df041186C844F8a2e2b63F16145Bc6Ff7d23E25")
    gold=Web3.to_checksum_address("0x576C260513204392F0eC0bc865450872025CB1cA")
    tears=Web3.to_checksum_address("0x79fE1fCF16Cc0F7E28b4d7B97387452E3084b6dA")



    Ambertaffy="0xB78d5580d6D897DE60E1A942A5C1dc07Bc716943"
    Milkweed="0xA2cef1763e59198025259d76Ce8F9E60d27B17B5"
    Darkweed="0x848Ac8ddC199221Be3dD4e4124c462B806B6C4Fd"
    Goldvein="0x0096ffda7A8f8E00e9F8Bbd1cF082c14FA9d642e"
    SpiderFruit="0x3E022D84D397F18743a90155934aBAC421D5FA4C"
    Ragweed="0x137995beEEec688296B0118131C1052546475fF3"
    Redleaf="0x473A41e71618dD0709Ba56518256793371427d79"
    Rockroot="0x60170664b52c035Fcb32CF5c9694b22b47882e5F"
    blue_stem="0x0776b936344DE7bd58A4738306a6c76835ce5D3F"
    Swift_Thistle="0x97b25DE9F61BBBA2aD51F1b706D4D7C04257f33A"
    Frost_Drum="0xe7a1B580942148451E47b92e95aEB8d31B0acA37"
    Knaproot="0xBcdD90034eB73e7Aec2598ea9082d381a285f63b"
    Shaggy_Caps="0x80A42Dc2909C0873294c5E359e8DF49cf21c74E4"
    Skunk_Shade="0xc6030Afa09EDec1fd8e63a1dE10fC00E0146DaF3"

    Bloater="0x268CC8248FFB72Cd5F3e73A9a20Fa2FF40EfbA61"
    Ironscale="0x04B43D632F34ba4D4D72B0Dc2DC4B30402e5Cf88"
    Lanterneye="0xc2Ff93228441Ff4DD904c60Ecbc1CfA2886C76eB"
    Redgill="0x68eE50dD7F1573423EE0Ed9c66Fc1A696f937e81"
    Sailfish="0x7f46E45f6e0361e7B9304f338404DA85CB94E33D"
    Shimmerskin="0xd44ee492889C078934662cfeEc790883DCe245f3"
    Silverfin="0xA7CFd21223151700FB82684Cd9c693596267375D"
    Frost_Bloater="0x3bcb9A3DaB194C6D8D44B424AF383E7Db51C82BD"
    Speckle_Tail="0xE7CB27ad646C49dC1671Cb9207176D864922C431"
    King_Pincer="0x60A3810a3963f23Fa70591435bbe93BF8786E202"
    Three_Eyed_Eel="0x6513757978E89e822772c16B60AE033781A29A4F"


    shvas="0x75E8D8676d774C9429FbB148b30E304b5542aC3d"
    moksha="0xCd2192521BD8e33559b0CA24f3260fE6A26C28e4"


    blue_egg="0xa61Bac689AD6867a605633520D70C49e1dCce853"
    grey_egg="0x7E121418cC5080C96d967cf6A033B0E541935097"
    green_egg="0x8D2bC53106063A37bb3DDFCa8CfC1D262a9BDCeB"
    yellow_egg="0x72F860bF73ffa3FC42B97BbcF43Ae80280CFcdc3"
    golden_egg="0xf2D479DaEdE7F9e270a90615F8b1C52F3C487bC7"


    health_vial="0x591853e01EcFDcF1Bdc9f093423C197BfBBd1A4f"
    full_health_potion="0x5948dd8Df6afEFE05B033AD8f3ae513a9Cd4F1Dc"
    mana_vial="0x240da5314B05E84392e868aC8f2b80ad6becadd4"
    full_mana_potion="0xf17FD21bDF6713a1Dfed668b97835b21e32651e8"
    anti_poison_potion="0x449eB718e351a86718A090A1a8Db3FD561306d9b"
    anti_blind_potion="0x5986045e7c221c8AD40A736B6434D82E29687aeB"
    magic_resistance_potion="0xFADCb72aAE2713975a890b59FF47231D1A552De3"
    toughness_potion="0x2dfFf745d2c7ddCAD4E97b80DF33705B1a95A172"
    stamina_vial="0x242078edFDca25ef2A497C8D9f256Fd641472E5F"
    swiftness_potion="0x84246Ce3988742D46fC00d9b8b2AFb5CDBDaE660"

    l_swiftness_crystall="0x6BCA53314dADdA7f4De30A95413f75a93bfAfecF"
    l_might_crystal="0x5bAC3cAd961B01Ef9510C8e6c5402A2bB1542831"
    l_finness_crystall="0x9d9ef1Bf6A46b8413bf6b1b54F6A7aAb53c6b1b6"
    l_vigor_crystall="0x5e4Cf6907CB5fBe2F642E399F6d07E567155d1F8"
    l_fortitude_crystall="0xbd2677c06C9448534A851bdD25dF045872b87cb1"
    l_wit_crystall="0xC989c916F189D2A2BE0322c020942d7c43aEa830"
    l_insight_crystall="0xbb5F97358F60cCBa262883A3Ff0C637393FE3aB8"
    l_fortune_crystall="0xE410b2BE2Ce1508E15009118567d02C6d7A7038e"
    l_chaos_crystall="0xeEe5b16Cc49e7cef65391Fe7325cea17f787e245"