from web3 import Web3

class AddressUniswapV3Polygon:
    route_v2=Web3.to_checksum_address('0x68b3465833fb72A70ecDF485E0e4C7bD8665Fc45')
    factory=Web3.to_checksum_address('0x1F98431c8aD98523631AE4a59f267346ea31F984')
    quoter_v2=Web3.to_checksum_address('0x61fFE014bA17989E743c5F6cB21bF9697530B21e')



class PolyTokens:
    usdc=Web3.to_checksum_address('0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174')
    usdt=Web3.to_checksum_address('0xc2132D05D31c914a87C6611C10748AEb04B58e8F')
    weth=Web3.to_checksum_address('0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619')
    wbtc=Web3.to_checksum_address('0x1BFD67037B42Cf73acF2047067bd4F2C47D9BfD6')
    dai=Web3.to_checksum_address('0x8f3Cf7ad23Cd3CaDbD9735AFf958023239c6A063')