from web3 import Web3

class SD:
    #dex
    sd_route=Web3.to_checksum_address('0x9e987E5E9aB872598f601BE4aCC5ac23F484845E')
    sd_factory=Web3.to_checksum_address('0x36fAE766e51f17F8218C735f58426E293498Db2B')

class AddressSD:
    #dex
    sd_route=Web3.to_checksum_address('0x9e987E5E9aB872598f601BE4aCC5ac23F484845E')
    sd_factory=Web3.to_checksum_address('0x36fAE766e51f17F8218C735f58426E293498Db2B')

class AddressKlaySwap:
    ks_route=Web3.to_checksum_address('0x6C14E2e4bae412137437A8Ec9e57263212d141A0')
    ks_factory=Web3.to_checksum_address('0xA15Be7e90df29A4aeaD0C7Fc86f7a9fBe6502Ac9')

class AddressSynapseKlay:
    sd_l1_bridge_zap=Web3.to_checksum_address('8671A0465844a15eb7230C5dd8d6032c26c655B7')
    
class AddressClaySwap:
    clay_swap_route=Web3.to_checksum_address('0xEf71750C100f7918d6Ded239Ff1CF09E81dEA92D')
    clay_swap_factory=Web3.to_checksum_address('0x3679c3766E70133Ee4A7eb76031E49d3d1f2B50c')

class KlayToken:
    #erc20
    ousdt=Web3.to_checksum_address('0xceE8FAF64bB97a73bb51E115Aa89C17FfA8dD167')
    oeth=Web3.to_checksum_address('0x34d21b1e550D73cee41151c77F3c73359527a396')
    owbtc=Web3.to_checksum_address('0x16D0e1fBD024c600Ca0380A4C5D57Ee7a2eCBf9c')
    jewel=Web3.to_checksum_address('0x30C103f8f5A3A732DFe2dCE1Cc9446f545527b43')
    gold=Web3.to_checksum_address('0xe7a1B580942148451E47b92e95aEB8d31B0acA37')
    tear=Web3.to_checksum_address('0x8Be0cbA3c8c8F392408364ef21dfCF714A918234')
    wavax=Web3.to_checksum_address('0xCd8fE44A29Db9159dB36f96570d7A4d91986f528')
    wklay=Web3.to_checksum_address('0x19Aac5f612f524B754CA7e7c41cbFa2E981A4432')
    jade=Web3.to_checksum_address('0xB3F5867E277798b50ba7A71C0b24FDcA03045eDF')
    claim=Web3.to_checksum_address('0xbA9725eaCCF07044625F1D232eF682216F5371c2')
    ousdc=Web3.to_checksum_address('0x754288077D0fF82AF7a5317C7CB8c444D421d103')
    kdai=Web3.to_checksum_address('0x5c74070FDeA071359b86082bd9f9b3dEaafbe32b')
    oxpr=Web3.to_checksum_address('0x9eaeFb09fe4aABFbE6b1ca316a3c36aFC83A393F')
