from web3 import Web3

class AddressJoe:
    #dex v2.1
    joe_quote_address=Web3.to_checksum_address('0x9Dbf1706577636941Ab5f443D2AEbE251ccd1648')
    joe_route_address=Web3.to_checksum_address('0xE3Ffc583dC176575eEA7FD9dF2A7c65F7E23f4C3')
    joe_factory_address=Web3.to_checksum_address('0x6E77932A92582f504FF6c4BdbCef7Da6c198aEEf')
    #dex
    joe_v2_factory_address=Web3.to_checksum_address('0x6E77932A92582f504FF6c4BdbCef7Da6c198aEEf')
    joe_v2_route_address=Web3.to_checksum_address('0xE3Ffc583dC176575eEA7FD9dF2A7c65F7E23f4C3')
    joe_v2_quote_address=Web3.to_checksum_address('0x9Dbf1706577636941Ab5f443D2AEbE251ccd1648')

    joe_v1_factory_address=Web3.to_checksum_address('0x9Ad6C38BE94206cA50bb0d90783181662f0Cfa10')
    joe_v1_route_address=Web3.to_checksum_address('0x60aE616a2155Ee3d9A68541Ba4544862310933d4')

class AddressPangolin:
    pan_factory_address=Web3.to_checksum_address('0xefa94DE7a4656D787667C749f7E1223D71E9FD88')
    pan_route_address=Web3.to_checksum_address('0xE54Ca86531e17Ef3616d22Ca28b0D458b6C89106')

class AddressAvaxTokens:
    #erc20
    wavax=Web3.to_checksum_address('0xB31f66AA3C1e785363F0875A1B74E27b85FD66c7')
    usdc=Web3.to_checksum_address('0xB97EF9Ef8734C71904D8002F8b6Bc66Dd9c48a6E')
    daie=Web3.to_checksum_address('0xd586E7F844cEa2F87f50152665BCbc2C279D8d70')
    usdt=Web3.to_checksum_address('0x9702230A8Ea53601f5cD2dc00fDBc13d4dF4A8c7')
    ethe=Web3.to_checksum_address('0x49D5c2BdFfac6CE2BFdB6640F4F80f226bc10bAB')
    btce=Web3.to_checksum_address('0x50b7545627a5162F82A992c33b87aDc75187B218')
    btcb=Web3.to_checksum_address('0x152b9d0FdC40C096757F570A51E494bd4b943E50')
    joe=Web3.to_checksum_address('0x6e84a6216eA6dACC71eE8E6b0a5B7322EEbC0fDd')
    gmx=Web3.to_checksum_address('0x62edc0692BD897D2295872a9FFCac5425011c661')



